@@ -217,6 +217,12 @@ bool Car2goEngine::authenticated()
     return !m_token.isEmpty() && !m_tokenSecret.isEmpty();
 }
 
+void Car2goEngine::clearAuthDetails()
+{
+    m_token.clear();
+    m_tokenSecret.clear();
+}
+
 bool Car2goEngine::createBooking(GMWVehicle *vehicle, const GMWAccount &account)
 {
     QByteArray requestUrl("https://www.car2go.com/api/v2.0/bookings");
