@@ -141,6 +141,7 @@ void MainWindow::setupAccount()
 {
 
     if(m_settingsDialog) {
+        qDebug() << "setting location to:" << m_settingsDialog->location();
         Core::engine()->setLocation(m_settingsDialog->location());
     }
 
@@ -179,12 +180,16 @@ void MainWindow::setupAccount()
         Core::engine()->refreshVehicles(false);
     } else {
         // No accounts for location... Print error message
-        QString message = tr("No accounts avaialble for this location");
+        QString message = tr("No accounts avaialble for this location or token expired. Please select your location and retry");
+        if(m_settingsDialog) {
+            m_settingsDialog->setAccountName("");
+        }
 #ifdef Q_WS_MAEMO_5
         QMaemo5InformationBox::information(NULL, message, QMaemo5InformationBox::DefaultTimeout);
 #else
         QMessageBox::information(this, "Error", message);
 #endif
+        Core::engine()->clearAuthDetails();
     }
 
     if(m_settingsDialog) {
@@ -309,6 +314,7 @@ void MainWindow::openSettings() {
 //        refreshAll(false);
     }
     delete m_settingsDialog;
+    m_settingsDialog = NULL;
 }
 
 void MainWindow::loadSettings(bool useCache)
