@@ -77,8 +77,8 @@ MobilityMap::MobilityMap(GMWItemSortFilterProxyModel *model, const QString &cach
     GMWMap(model, parent),
     m_serviceProvider(0),
     m_map(0),
-    m_cacheDir(cacheDir),
-    m_positionMarker(0)
+    m_positionMarker(0),
+    m_cacheDir(cacheDir)
 {
     QGraphicsScene *scene = new QGraphicsScene;
     m_view = new MapView(scene, this);
